
# -----------------------------------------------------------------------
# hit
# -----------------------------------------------------------------------
drop table if exists hit;

CREATE TABLE hit
(
        hit_id INTEGER NOT NULL AUTO_INCREMENT,
        primer_id INTEGER NOT NULL,
        target_USA VARCHAR (255),
        target_position INTEGER,
        target_strand BIT,
        mismatches INTEGER,
        creator VARCHAR (40),
    PRIMARY KEY(hit_id)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# pcr_product
# -----------------------------------------------------------------------
drop table if exists pcr_product;

CREATE TABLE pcr_product
(
        pcr_product_id INTEGER NOT NULL AUTO_INCREMENT,
        left_hit_id INTEGER NOT NULL,
        right_hit_id INTEGER NOT NULL,
        sequence MEDIUMTEXT,
        seqlen INTEGER,
        tm DOUBLE,
        gc DOUBLE,
        status INTEGER,
    PRIMARY KEY(pcr_product_id),
    FOREIGN KEY (left_hit_id) REFERENCES hit (hit_id),
    FOREIGN KEY (right_hit_id) REFERENCES hit (hit_id)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# primer
# -----------------------------------------------------------------------
drop table if exists primer;

CREATE TABLE primer
(
        primer_id INTEGER NOT NULL AUTO_INCREMENT,
        local_name VARCHAR (80),
        sequence VARCHAR (255) NOT NULL,
        seqlen INTEGER NOT NULL,
        tm DOUBLE,
        gc DOUBLE,
        status INTEGER,
    PRIMARY KEY(primer_id),
    INDEX local_name_idx (local_name)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# project
# -----------------------------------------------------------------------
drop table if exists project;

CREATE TABLE project
(
        project_id INTEGER NOT NULL AUTO_INCREMENT,
        name VARCHAR (255) NOT NULL,
        shortname VARCHAR (40) NOT NULL,
        directory_path MEDIUMTEXT,
        parent_id INTEGER,
    PRIMARY KEY(project_id),
    FOREIGN KEY (parent_id) REFERENCES project (project_id)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# project_hit
# -----------------------------------------------------------------------
drop table if exists project_hit;

CREATE TABLE project_hit
(
        project_id INTEGER NOT NULL,
        hit_id INTEGER NOT NULL,
    FOREIGN KEY (project_id) REFERENCES project (project_id),
    FOREIGN KEY (hit_id) REFERENCES hit (hit_id)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# project_primer
# -----------------------------------------------------------------------
drop table if exists project_primer;

CREATE TABLE project_primer
(
        project_id INTEGER NOT NULL,
        primer_id INTEGER NOT NULL,
    FOREIGN KEY (project_id) REFERENCES project (project_id),
    FOREIGN KEY (primer_id) REFERENCES primer (primer_id)
) TYPE = InnoDB;

# -----------------------------------------------------------------------
# project_pcr_product
# -----------------------------------------------------------------------
drop table if exists project_pcr_product;

CREATE TABLE project_pcr_product
(
        project_id INTEGER NOT NULL,
        pcr_product_id INTEGER NOT NULL,
    FOREIGN KEY (project_id) REFERENCES project (project_id),
    FOREIGN KEY (pcr_product_id) REFERENCES pcr_product (pcr_product_id)
) TYPE = InnoDB;
  
  
  
  
  
  
  
