import java.io.*;
import java.util.*;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import de.vahrson.blast.UrlBlastArgs;
import de.vahrson.blast.UrlBlastClient;
import de.vahrson.io.FastaReader;
import de.vahrson.seq.Sequence;
import de.vahrson.seq.SequenceFormatter;
import de.vahrson.util.StopWatch;

/*
 * Created on 19.04.2004
 *
 * $Header: /Users/wova/laufend/cvs/UrlBlast/urlblast.java,v 1.4 2004/04/26 10:09:50 wova Exp $
 *  */

/**
 * @author wova
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class urlblast {
	private Reader fIn;
	private Properties fQuery;
	private UrlBlastArgs fArgHandler;
	
	private static final String VERSION_INFO="urlblast Version 0.9 23apr2004 Copyright 2004 Dr. Wolfgang Vahrson. All Rights Reserved.";

	static private Logger log= Logger.getLogger(urlblast.class);

	public urlblast(String[] args) throws Exception {
		super();
		initLog();
		fArgHandler= new UrlBlastArgs(args);
		fQuery= new Properties();
		initQuery();
		
		fIn= null;
		initReader();
		
	}

	public static void main(String[] args) {
		try {
			new urlblast(args).run();
		}
		catch (Exception e) {
			e.printStackTrace(System.err);
		}
	}

	public void run() {
		if (fArgHandler.isWantVersion()) {
			version();
		}
		if ( fArgHandler.isWantHelp()) {
			help();
			System.exit(0);
		}
		
		int count= 0;
		try {
			log.info(VERSION_INFO);
			log.info(new Date());
			StopWatch totalTime= new StopWatch();
			FastaReader r= new FastaReader(fIn);
			Sequence s;
			while (null != (s= r.nextSequence())) {
				StopWatch currentTime= new StopWatch();

				count++;
				log.info("Sequence " + count + ". " + s.getName());
				fQuery.setProperty("put.query", new SequenceFormatter().formatAsFastA(s));
				UrlBlastClient b= new UrlBlastClient(fQuery, fArgHandler.getOutput());
				b.setWantInfo(fArgHandler.isWantInfo());
				b.setWantQuery(fArgHandler.isWantEcho());
				b.run();
				
				currentTime.stop();
				log.info("Sequence " + count + " done after " + currentTime.toString());
				
			}
			totalTime.stop();
			log.info("urlblast done. " + count + " sequences in " + totalTime.toString() );
		}
		catch (Exception e) {
			log.error("Exception in run reading sequence #" + count);
		}
	}

	void initLog() {
		PropertyConfigurator.configure(System.getProperty("log4j.properties", "log4j.properties"));
	}

	void help() {
			System.err.println(fArgHandler.documentation());		
	}
	
	void version() {
		PrintWriter p= new PrintWriter(new OutputStreamWriter(fArgHandler.getOutput()));
		p.println(VERSION_INFO);
		p.flush();
	}

	void initQuery() throws IOException {
		InputStream loadStream= fArgHandler.getQueryOptions();
		if (loadStream != null) {
			fQuery.load(loadStream);
		}
	}

	void initReader() throws FileNotFoundException {
		fIn= new InputStreamReader( fArgHandler.getSequences());
	}
}
